======
README
======

Summary
=======

Installs rdalal on your system.


Install
=======

::

    $ pip install https://github.com/willkg/rdalal/archive/master.zip


Install for development
=======================

::

    $ git clone https://github.com/willkg/rdalal/
    $ mkvirtualenv rdalal
    $ pip install -e .


Run for some sweet tunes
========================

::

    $ rdalal
